@@ -197,7 +197,7 @@ public final class MimeSnippetManagement implements SnippetManagement {
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
-            final StringBuilder sql = new StringBuilder("SELECT id FROM snippet WHERE cid=? AND (user=? OR shared>0) AND refType=").append(FS_TYPE);
+            final com.openexchange.java.StringAllocator sql = new com.openexchange.java.StringAllocator("SELECT id FROM snippet WHERE cid=? AND (user=? OR shared>0) AND refType=").append(FS_TYPE);
             final boolean hasTypes = (null != types) && (types.length > 0);
             if (hasTypes) {
                 sql.append(" AND (");
@@ -251,7 +251,7 @@ public final class MimeSnippetManagement implements SnippetManagement {
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
-            final StringBuilder sql = new StringBuilder("SELECT id FROM snippet WHERE cid=? AND user=? AND refType=").append(FS_TYPE);
+            final com.openexchange.java.StringAllocator sql = new com.openexchange.java.StringAllocator("SELECT id FROM snippet WHERE cid=? AND user=? AND refType=").append(FS_TYPE);
             stmt = con.prepareStatement(sql.toString());
             int pos = 0;
             stmt.setInt(++pos, contextId);
@@ -717,7 +717,7 @@ public final class MimeSnippetManagement implements SnippetManagement {
                 try {
                     /*-
                      * Update DB, too
-                     * 
+                     *
                      * 1. Create dummy entry to check DB schema consistency
                      * 2. Delete existing
                      * 3. Make dummy entry the real entry
